/********************************************************************************
** Form generated from reading UI file 'settingswindow.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SETTINGSWINDOW_H
#define UI_SETTINGSWINDOW_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_SettingsWindow
{
public:
    QHBoxLayout *horizontalLayout;
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox_2;
    QHBoxLayout *horizontalLayout_5;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout_4;
    QRadioButton *bgDefaultRadioButton;
    QRadioButton *bgCustomRadioButton;
    QHBoxLayout *horizontalLayout_3;
    QLineEdit *bgLineEdit;
    QToolButton *bgToolButton;
    QGroupBox *groupBox_3;
    QHBoxLayout *horizontalLayout_6;
    QGridLayout *gridLayout_2;
    QLabel *fontColorSolvedLabel;
    QLabel *fontColorUnsolvedLabel;
    QPushButton *fontColorSolvedPushButton;
    QPushButton *fontColorUnsolvedPushButton;
    QGroupBox *groupBox;
    QHBoxLayout *horizontalLayout_2;
    QGridLayout *gridLayout;
    QLabel *label_2;
    QSpinBox *heightSpinBox;
    QLabel *label_3;
    QSpinBox *widthSpinBox;
    QCheckBox *preventMistakesCheckBox;
    QLabel *label_4;
    QSlider *densitySlider;
    QLabel *label_5;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *SettingsWindow)
    {
        if (SettingsWindow->objectName().isEmpty())
            SettingsWindow->setObjectName("SettingsWindow");
        SettingsWindow->resize(374, 395);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(SettingsWindow->sizePolicy().hasHeightForWidth());
        SettingsWindow->setSizePolicy(sizePolicy);
        horizontalLayout = new QHBoxLayout(SettingsWindow);
        horizontalLayout->setObjectName("horizontalLayout");
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        groupBox_2 = new QGroupBox(SettingsWindow);
        groupBox_2->setObjectName("groupBox_2");
        horizontalLayout_5 = new QHBoxLayout(groupBox_2);
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        bgDefaultRadioButton = new QRadioButton(groupBox_2);
        bgDefaultRadioButton->setObjectName("bgDefaultRadioButton");
        bgDefaultRadioButton->setChecked(true);

        horizontalLayout_4->addWidget(bgDefaultRadioButton);

        bgCustomRadioButton = new QRadioButton(groupBox_2);
        bgCustomRadioButton->setObjectName("bgCustomRadioButton");

        horizontalLayout_4->addWidget(bgCustomRadioButton);


        verticalLayout_2->addLayout(horizontalLayout_4);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        bgLineEdit = new QLineEdit(groupBox_2);
        bgLineEdit->setObjectName("bgLineEdit");
        bgLineEdit->setReadOnly(true);

        horizontalLayout_3->addWidget(bgLineEdit);

        bgToolButton = new QToolButton(groupBox_2);
        bgToolButton->setObjectName("bgToolButton");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("document-open")));
        bgToolButton->setIcon(icon);

        horizontalLayout_3->addWidget(bgToolButton);


        verticalLayout_2->addLayout(horizontalLayout_3);


        horizontalLayout_5->addLayout(verticalLayout_2);


        verticalLayout->addWidget(groupBox_2);

        groupBox_3 = new QGroupBox(SettingsWindow);
        groupBox_3->setObjectName("groupBox_3");
        horizontalLayout_6 = new QHBoxLayout(groupBox_3);
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName("gridLayout_2");
        fontColorSolvedLabel = new QLabel(groupBox_3);
        fontColorSolvedLabel->setObjectName("fontColorSolvedLabel");
        QFont font;
        font.setBold(true);
        fontColorSolvedLabel->setFont(font);
        fontColorSolvedLabel->setTextFormat(Qt::AutoText);

        gridLayout_2->addWidget(fontColorSolvedLabel, 0, 0, 1, 1);

        fontColorUnsolvedLabel = new QLabel(groupBox_3);
        fontColorUnsolvedLabel->setObjectName("fontColorUnsolvedLabel");
        fontColorUnsolvedLabel->setFont(font);
        fontColorUnsolvedLabel->setTextFormat(Qt::AutoText);

        gridLayout_2->addWidget(fontColorUnsolvedLabel, 1, 0, 1, 1);

        fontColorSolvedPushButton = new QPushButton(groupBox_3);
        fontColorSolvedPushButton->setObjectName("fontColorSolvedPushButton");

        gridLayout_2->addWidget(fontColorSolvedPushButton, 0, 1, 1, 1);

        fontColorUnsolvedPushButton = new QPushButton(groupBox_3);
        fontColorUnsolvedPushButton->setObjectName("fontColorUnsolvedPushButton");

        gridLayout_2->addWidget(fontColorUnsolvedPushButton, 1, 1, 1, 1);


        horizontalLayout_6->addLayout(gridLayout_2);


        verticalLayout->addWidget(groupBox_3);

        groupBox = new QGroupBox(SettingsWindow);
        groupBox->setObjectName("groupBox");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(groupBox->sizePolicy().hasHeightForWidth());
        groupBox->setSizePolicy(sizePolicy1);
        horizontalLayout_2 = new QHBoxLayout(groupBox);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        label_2 = new QLabel(groupBox);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(label_2, 0, 0, 1, 1);

        heightSpinBox = new QSpinBox(groupBox);
        heightSpinBox->setObjectName("heightSpinBox");
        heightSpinBox->setMinimum(5);
        heightSpinBox->setMaximum(50);

        gridLayout->addWidget(heightSpinBox, 0, 1, 1, 1);

        label_3 = new QLabel(groupBox);
        label_3->setObjectName("label_3");
        label_3->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(label_3, 1, 0, 1, 1);

        widthSpinBox = new QSpinBox(groupBox);
        widthSpinBox->setObjectName("widthSpinBox");
        widthSpinBox->setMinimum(5);
        widthSpinBox->setMaximum(50);

        gridLayout->addWidget(widthSpinBox, 1, 1, 1, 1);

        preventMistakesCheckBox = new QCheckBox(groupBox);
        preventMistakesCheckBox->setObjectName("preventMistakesCheckBox");
        preventMistakesCheckBox->setChecked(false);

        gridLayout->addWidget(preventMistakesCheckBox, 3, 1, 1, 1);

        label_4 = new QLabel(groupBox);
        label_4->setObjectName("label_4");
        label_4->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(label_4, 2, 0, 1, 1);

        densitySlider = new QSlider(groupBox);
        densitySlider->setObjectName("densitySlider");
        densitySlider->setMinimum(30);
        densitySlider->setMaximum(70);
        densitySlider->setPageStep(5);
        densitySlider->setValue(55);
        densitySlider->setOrientation(Qt::Horizontal);
        densitySlider->setInvertedAppearance(false);
        densitySlider->setTickPosition(QSlider::TicksAbove);
        densitySlider->setTickInterval(5);

        gridLayout->addWidget(densitySlider, 2, 1, 1, 1);

        label_5 = new QLabel(groupBox);
        label_5->setObjectName("label_5");
        label_5->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(label_5, 3, 0, 1, 1);


        horizontalLayout_2->addLayout(gridLayout);


        verticalLayout->addWidget(groupBox);

        buttonBox = new QDialogButtonBox(SettingsWindow);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        horizontalLayout->addLayout(verticalLayout);

        QWidget::setTabOrder(bgDefaultRadioButton, bgCustomRadioButton);
        QWidget::setTabOrder(bgCustomRadioButton, bgLineEdit);
        QWidget::setTabOrder(bgLineEdit, bgToolButton);
        QWidget::setTabOrder(bgToolButton, heightSpinBox);
        QWidget::setTabOrder(heightSpinBox, widthSpinBox);
        QWidget::setTabOrder(widthSpinBox, densitySlider);
        QWidget::setTabOrder(densitySlider, preventMistakesCheckBox);
        QWidget::setTabOrder(preventMistakesCheckBox, buttonBox);

        retranslateUi(SettingsWindow);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, SettingsWindow, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, SettingsWindow, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(SettingsWindow);
    } // setupUi

    void retranslateUi(QDialog *SettingsWindow)
    {
        SettingsWindow->setWindowTitle(tr2i18n("Settings", nullptr));
        groupBox_2->setTitle(tr2i18n("Background Image", nullptr));
        bgDefaultRadioButton->setText(tr2i18n("Default", "default background image"));
        bgCustomRadioButton->setText(tr2i18n("Custom", "custom background image"));
        groupBox_3->setTitle(tr2i18n("Font Colors", nullptr));
        fontColorSolvedLabel->setText(tr2i18n("Solved streaks:", nullptr));
        fontColorUnsolvedLabel->setText(tr2i18n("Unsolved streaks:", nullptr));
        fontColorSolvedPushButton->setText(tr2i18n("Edit\342\200\246", nullptr));
        fontColorUnsolvedPushButton->setText(tr2i18n("Edit\342\200\246", nullptr));
        groupBox->setTitle(tr2i18n("Custom Difficulty", nullptr));
        label_2->setText(tr2i18n("Height:", nullptr));
        heightSpinBox->setSuffix(QString());
        label_3->setText(tr2i18n("Width:", nullptr));
        label_4->setText(tr2i18n("Density:", nullptr));
        label_5->setText(tr2i18n("Prevent mistakes:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SettingsWindow: public Ui_SettingsWindow {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SETTINGSWINDOW_H

