/*
    SPDX-FileCopyrightText: 2015 Jakob Gruber <jakob.gruber@gmail.com>

    SPDX-License-Identifier: GPL-2.0-or-later
*/

#ifndef CONSTANTS_H
#define CONSTANTS_H

const int ZVALUE_HIGHLIGHT = -3;
const int ZVALUE_CELLFRAME = 0;
const int ZVALUE_STREAKFRAME = 0;
const int ZVALUE_DIVIDER = 3;
const int ZVALUE_CELLITEM = 7;
const int ZVALUE_BANNER = 7;
const int ZVALUE_STREAKTEXT = 7;
const int SECTION_SIZE = 5;

#endif // CONSTANTS_H
