/********************************************************************************
** Form generated from reading UI file 'selectboardwindow.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SELECTBOARDWINDOW_H
#define UI_SELECTBOARDWINDOW_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QTableView>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_LevelSelectUi
{
public:
    QHBoxLayout *horizontalLayout_2;
    QHBoxLayout *horizontalLayout;
    QTableView *tableView;
    QGridLayout *gridLayout;
    QLabel *labelAuthor;
    QLabel *labelName;
    QLabel *labelImage;
    QLabel *labelSolved;
    QLabel *labelSize;
    QLabel *labelDifficulty;

    void setupUi(QWidget *LevelSelectUi)
    {
        if (LevelSelectUi->objectName().isEmpty())
            LevelSelectUi->setObjectName("LevelSelectUi");
        LevelSelectUi->setWindowModality(Qt::ApplicationModal);
        LevelSelectUi->resize(700, 350);
        LevelSelectUi->setMinimumSize(QSize(700, 350));
        horizontalLayout_2 = new QHBoxLayout(LevelSelectUi);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        tableView = new QTableView(LevelSelectUi);
        tableView->setObjectName("tableView");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(tableView->sizePolicy().hasHeightForWidth());
        tableView->setSizePolicy(sizePolicy);
        tableView->setProperty("showDropIndicator", QVariant(false));
        tableView->setAlternatingRowColors(false);
        tableView->setSelectionMode(QAbstractItemView::SingleSelection);
        tableView->setSelectionBehavior(QAbstractItemView::SelectRows);
        tableView->setShowGrid(false);
        tableView->setGridStyle(Qt::NoPen);
        tableView->setSortingEnabled(true);
        tableView->setWordWrap(false);
        tableView->setCornerButtonEnabled(false);
        tableView->horizontalHeader()->setVisible(true);
        tableView->horizontalHeader()->setStretchLastSection(true);
        tableView->verticalHeader()->setVisible(false);

        horizontalLayout->addWidget(tableView);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        labelAuthor = new QLabel(LevelSelectUi);
        labelAuthor->setObjectName("labelAuthor");

        gridLayout->addWidget(labelAuthor, 1, 0, 1, 1);

        labelName = new QLabel(LevelSelectUi);
        labelName->setObjectName("labelName");

        gridLayout->addWidget(labelName, 0, 0, 1, 1);

        labelImage = new QLabel(LevelSelectUi);
        labelImage->setObjectName("labelImage");
        sizePolicy.setHeightForWidth(labelImage->sizePolicy().hasHeightForWidth());
        labelImage->setSizePolicy(sizePolicy);
        QFont font;
        font.setPointSize(24);
        labelImage->setFont(font);
        labelImage->setStyleSheet(QString::fromUtf8("background-color: rgb(255, 255, 255);"));
        labelImage->setFrameShape(QFrame::Box);
        labelImage->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(labelImage, 5, 0, 1, 1);

        labelSolved = new QLabel(LevelSelectUi);
        labelSolved->setObjectName("labelSolved");

        gridLayout->addWidget(labelSolved, 4, 0, 1, 1);

        labelSize = new QLabel(LevelSelectUi);
        labelSize->setObjectName("labelSize");

        gridLayout->addWidget(labelSize, 2, 0, 1, 1);

        labelDifficulty = new QLabel(LevelSelectUi);
        labelDifficulty->setObjectName("labelDifficulty");

        gridLayout->addWidget(labelDifficulty, 3, 0, 1, 1);


        horizontalLayout->addLayout(gridLayout);


        horizontalLayout_2->addLayout(horizontalLayout);


        retranslateUi(LevelSelectUi);

        QMetaObject::connectSlotsByName(LevelSelectUi);
    } // setupUi

    void retranslateUi(QWidget *LevelSelectUi)
    {
        LevelSelectUi->setWindowTitle(tr2i18n("Level Selection", nullptr));
        labelAuthor->setText(tr2i18n("Author: -", nullptr));
        labelName->setText(tr2i18n("Name: -", nullptr));
        labelImage->setText(tr2i18n("?", nullptr));
        labelSolved->setText(tr2i18n("Solved: -", nullptr));
        labelSize->setText(tr2i18n("Size: -", nullptr));
        labelDifficulty->setText(tr2i18n("Difficulty: -", nullptr));
    } // retranslateUi

};

namespace Ui {
    class LevelSelectUi: public Ui_LevelSelectUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SELECTBOARDWINDOW_H

